@@ -35,11 +35,14 @@
 #' \item var_name: character (e.g., Percent / '%')
 #' \item bluemarble: TRUE / FALSE
 #' \item mirror_data: TRUE / FALSE / NP / SP
+#' \item namin: numeric (e.g., 2e-04), minimum in case of no data
 #' \item scale_factor: numeric (e.g., 1)
 #' \item smooth_factor: numeric (e.g., 1)
 #' \item aux_file: path to optional aux-file, including CLAAS level 2 lon/ lat data
 #' \item sysd: path to optional sysdata.rda file, which includes bluemarble data
 #' \item remap: remap data to regular grid. TRUE / FALSE
+#' \item tri_up: plot upper triangle on colorscale. TRUE / FALSE
+#' \item tri_down: plot lower triangle on colorscale. TRUE / FALSE
 #' }
 #'@export
 #'@importFrom assertthat assert_that is.count is.flag is.readable is.writeable
@@ -267,11 +270,14 @@ quicklook <- function(config,
   sysd <- c()
   auxf <- c()
   mirror <- c()
+  namin <- c()
   logsc <- c()
   scalef <- c()
   smoothf <- c()
   tick_lab <- vector(mode = "list", length = 1)
   remap_q <- FALSE
+  triup <- c()
+  tridown <- c()
   
   # define plotting area in case of polar projection
   area <- ""
@@ -279,7 +285,6 @@ quicklook <- function(config,
   if (grepl("South", file_info$area)) area <- "SP"
   if (grepl("Global", file_info$area)) area <- "GL"
   
-  # vars <- names(configParams[[file_info$product_type]][[file_info$id]])[names(configParams[[file_info$product_type]][[file_info$id]]) != "Dataset"]
   vars <- names(configParams[[file_info$product_type]][[file_info$id]])
   vars <- vars[!(vars %in% c("remap", "aux_file", "Dataset"))]
   nvars <- length(vars)
@@ -325,6 +330,12 @@ quicklook <- function(config,
     }
     scalef <- append(scalef, scfa)
     
+    inamin <- configParams[[file_info$product_type]][[file_info$id]][[vars[i]]]$namin
+    if (is.null(inamin)) {
+      inamin <- NA
+    }
+    namin <- append(namin, inamin)
+    
     tl <- configParams[[file_info$product_type]][[file_info$id]][[vars[i]]]$tick_lab
     if (is.null(tl)) {
       tl <- NA
@@ -349,6 +360,18 @@ quicklook <- function(config,
     }
     logsc <- append(logsc, ilogsc)
     
+    itriup <- configParams[[file_info$product_type]][[file_info$id]][[vars[i]]]$tri_up
+    if (is.null(itriup)) {
+      itriup <- FALSE
+    }
+    triup <- append(triup, itriup)
+    
+    itridown <- configParams[[file_info$product_type]][[file_info$id]][[vars[i]]]$tri_down
+    if (is.null(itridown)) {
+      itridown <- FALSE
+    }
+    tridown <- append(tridown, itridown)
+    
     col_from_config <- c(col_from_config, configParams[[file_info$product_type]][[file_info$id]][[vars[i]]]$colorscale)
     if (logo) logos <- c(logos, configParams[[file_info$product_type]][[file_info$id]][[vars[i]]]$logo)
   }
@@ -607,12 +630,15 @@ quicklook <- function(config,
       graphics::par(mfrow = c(nrows, ncols))
       graphics::par(mar = c(2, 4, 4, 6) + 0.1)
       graphics::par(oma = c(0, 0, 2, 5))
+      graphics::par(family = "Liberation Sans")
     }  else if (area == "GL") {
         graphics::par(mar = c(2, 0, 4, 5) + 0.1)
         graphics::par(oma = c(0, 0, 1, 1))
+        graphics::par(family = "Liberation Sans")
     } else {
         graphics::par(mar = c(2, 4, 4, 7) + 0.1)
         graphics::par(oma = c(0, 0, 1, 2))
+        graphics::par(family = "Liberation Sans")
     }
 
     for (j in seq_along(vars)) {
@@ -655,7 +681,15 @@ quicklook <- function(config,
           
           if (plot_lim[j,1] == 0) {
             datav <- raster::as.matrix(stacks[[j]][[slot_i]])
-            minval <- min(datav[datav > 0], na.rm = TRUE)
+            if (all(is.na(datav))) {
+              if (!is.na(namin[j])){
+                minval <- as.numeric(namin[j])
+              } else {
+                  minval <- 0.001
+              }
+            } else {
+                minval <- min(datav[datav > 0], na.rm = TRUE)
+            }
             tick_lim[1] <- minval
             logzero <- TRUE
             ticks <- get_breaks(tick_lim)
@@ -1422,24 +1456,46 @@ quicklook <- function(config,
                        col = col,
                        add = TRUE)
            } else {
-             raster::plot(stacks[[j]] * scalef[j], y = slot_i,
-                          main = "",
-                          axes = FALSE,
-                          xlab = "",
-                          ylab = "",
-                          zlim = plot_lim[j,],
-                          legend.only = TRUE,
-                          legend.shrink = 0.9,
-                          legend.width = 1.5,
-                          legend.mar = 5.1,
-                          legend.args=list(text = units[j], 
-                                           side = 2, 
-                                           font = 2, 
-                                           line = 0.2, 
-                                           cex = 1.25*fsf),
-                       axis.args=list(cex.axis = 1*fsf),
-                       col = col,
-                       add = TRUE)
+             if (triup[j] || tridown[j]){
+               datav <- raster::as.matrix(stacks[[j]][[slot_i]])
+               
+               fields::imagePlot(datav, 
+                                 zlim = plot_lim[j,],   
+                                 legend.only = TRUE,
+                                 legend.shrink = 0.9,
+                                 legend.width = 1.5,
+                                 legend.mar = 5.1,
+                                 legend.args=list(text = units[j], 
+                                                  side = 2, 
+                                                  font = 2, 
+                                                  line = 0.2, 
+                                                  cex = 1.25*fsf),
+                                 axis.args=list(cex.axis = 1*fsf),
+                                 col = col,
+                                 upperTriangle = triup[j],
+                                 lowerTriangle = tridown[j],
+                                 add = TRUE)
+             } else {
+                 raster::plot(stacks[[j]] * scalef[j], y = slot_i,
+                            main = "",
+                            axes = FALSE,
+                            xlab = "",
+                            ylab = "",
+                            zlim = plot_lim[j,],
+                            legend.only = TRUE,
+                            legend.shrink = 0.9,
+                            legend.width = 1.5,
+                            legend.mar = 5.1,
+                            legend.args=list(text = units[j], 
+                                             side = 2, 
+                                             font = 2, 
+                                             line = 0.2, 
+                                             cex = 1.25*fsf),
+                            axis.args=list(cex.axis = 1*fsf),
+                            col = col,
+                            add = TRUE)
+             }
+             
            }
         }
       }
